==> pollen-business-1.0.1-sources.jar: org/chorem/pollen/business/persistence/PreventRule.java <==
/* *##%
 Copyright (C) 2009 Pollen
 *##%*/
package org.chorem.pollen.business.persistence;

import org.nuiton.topia.persistence.SearchFields;
import org.nuiton.topia.persistence.TopiaEntity;

@SearchFields (
  txtFields={"scope","method"},
  numFields={"sensibility"},
  boolFields={"repeated"}
)        
public interface PreventRule extends TopiaEntity {

    public static final String SCOPE = "scope";

    public static final String SENSIBILITY = "sensibility";

    public static final String REPEATED = "repeated";

    public static final String METHOD = "method";

    public static final String POLL = "poll";

    /**
     * @param scope La valeur de l'attribut scope à positionner.
     */
    public void setScope(java.lang.String scope);

    /**
     * @return La valeur de l'attribut scope.
     */
    public java.lang.String getScope();

    /**
     * @param sensibility La valeur de l'attribut sensibility à positionner.
     */
    public void setSensibility(int sensibility);

    /**
     * @return La valeur de l'attribut sensibility.
     */
    public int getSensibility();

    /**
     * @param repeated La valeur de l'attribut repeated à positionner.
     */
    public void setRepeated(java.lang.Boolean repeated);

    /**
     * @return La valeur de l'attribut repeated.
     */
    public java.lang.Boolean getRepeated();

    /**
     * @param method La valeur de l'attribut method à positionner.
     */
    public void setMethod(java.lang.String method);

    /**
     * @return La valeur de l'attribut method.
     */
    public java.lang.String getMethod();

    /**
     * @param poll La valeur de l'attribut poll à positionner.
     */
    public void setPoll(org.chorem.pollen.business.persistence.Poll poll);

    /**
     * @return La valeur de l'attribut poll.
     */
    public org.chorem.pollen.business.persistence.Poll getPoll();

} //PreventRule

==> pollen-business-1.2.2-sources.jar: org/chorem/pollen/business/persistence/PreventRule.java <==
/* *##%
 Copyright (C) 2009 Pollen
 *##%*/
package org.chorem.pollen.business.persistence;

import org.nuiton.topia.persistence.SearchFields;
import org.nuiton.topia.persistence.TopiaEntity;

@SearchFields (
  txtFields={"scope","method"},
  numFields={"sensibility"},
  boolFields={"repeated","active","oneTime"}
)        
public interface PreventRule extends TopiaEntity {

    public static final String SCOPE = "scope";

    public static final String SENSIBILITY = "sensibility";

    public static final String REPEATED = "repeated";

    public static final String ACTIVE = "active";

    public static final String ONE_TIME = "oneTime";

    public static final String METHOD = "method";

    public static final String POLL = "poll";

    /**
     * @param scope La valeur de l'attribut scope à positionner.
     */
    public void setScope(java.lang.String scope);

    /**
     * @return La valeur de l'attribut scope.
     */
    public java.lang.String getScope();

    /**
     * @param sensibility La valeur de l'attribut sensibility à positionner.
     */
    public void setSensibility(java.lang.Integer sensibility);

    /**
     * @return La valeur de l'attribut sensibility.
     */
    public java.lang.Integer getSensibility();

    /**
     * @param repeated La valeur de l'attribut repeated à positionner.
     */
    public void setRepeated(java.lang.Boolean repeated);

    /**
     * @return La valeur de l'attribut repeated.
     */
    public java.lang.Boolean getRepeated();

    /**
     * @param active La valeur de l'attribut active à positionner.
     */
    public void setActive(java.lang.Boolean active);

    /**
     * @return La valeur de l'attribut active.
     */
    public java.lang.Boolean getActive();

    /**
     * @param oneTime La valeur de l'attribut oneTime à positionner.
     */
    public void setOneTime(java.lang.Boolean oneTime);

    /**
     * @return La valeur de l'attribut oneTime.
     */
    public java.lang.Boolean getOneTime();

    /**
     * @param method La valeur de l'attribut method à positionner.
     */
    public void setMethod(java.lang.String method);

    /**
     * @return La valeur de l'attribut method.
     */
    public java.lang.String getMethod();

    /**
     * @param poll La valeur de l'attribut poll à positionner.
     */
    public void setPoll(org.chorem.pollen.business.persistence.Poll poll);

    /**
     * @return La valeur de l'attribut poll.
     */
    public org.chorem.pollen.business.persistence.Poll getPoll();

} //PreventRule
